/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VaultClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the HCP Vault cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#cluster_id VaultCluster#cluster_id}
    */
    readonly clusterId: string;
    /**
    * The ID of the HVN this HCP Vault cluster is associated to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#hvn_id VaultCluster#hvn_id}
    */
    readonly hvnId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#id VaultCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The minimum Vault version to use when creating the cluster. If not specified, it is defaulted to the version that is currently recommended by HCP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#min_vault_version VaultCluster#min_vault_version}
    */
    readonly minVaultVersion?: string;
    /**
    * The performance replication [paths filter](https://developer.hashicorp.com/vault/tutorials/cloud-ops/vault-replication-terraform). Applies to performance replication secondaries only and operates in "deny" mode only.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#paths_filter VaultCluster#paths_filter}
    */
    readonly pathsFilter?: string[];
    /**
    * The `self_link` of the HCP Vault Plus tier cluster which is the primary in the performance replication setup with this HCP Vault Plus tier cluster. If not specified, it is a standalone Plus tier HCP Vault cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#primary_link VaultCluster#primary_link}
    */
    readonly primaryLink?: string;
    /**
    *
    * The ID of the HCP project where the Vault cluster is located.
    * If not specified, the project specified in the HCP Provider config block will be used, if configured.
    * If a project is not configured in the HCP Provider config block, the oldest project in the organization will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#project_id VaultCluster#project_id}
    */
    readonly projectId?: string;
    /**
    * Denotes that the cluster has a proxy endpoint. Valid options are `ENABLED`, `DISABLED`. Defaults to `DISABLED`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#proxy_endpoint VaultCluster#proxy_endpoint}
    */
    readonly proxyEndpoint?: string;
    /**
    * Denotes that the cluster has a public endpoint. Defaults to false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#public_endpoint VaultCluster#public_endpoint}
    */
    readonly publicEndpoint?: boolean | cdktf.IResolvable;
    /**
    * Tier of the HCP Vault cluster. Valid options for tiers - `dev`, `starter_small`, `standard_small`, `standard_medium`, `standard_large`, `plus_small`, `plus_medium`, `plus_large`. See [pricing information](https://www.hashicorp.com/products/vault/pricing). Changing a cluster's size or tier is only available to admins. See [Scale a cluster](https://registry.terraform.io/providers/hashicorp/hcp/latest/docs/guides/vault-scaling).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#tier VaultCluster#tier}
    */
    readonly tier?: string;
    /**
    * audit_log_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#audit_log_config VaultCluster#audit_log_config}
    */
    readonly auditLogConfig?: VaultClusterAuditLogConfig;
    /**
    * major_version_upgrade_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#major_version_upgrade_config VaultCluster#major_version_upgrade_config}
    */
    readonly majorVersionUpgradeConfig?: VaultClusterMajorVersionUpgradeConfig;
    /**
    * metrics_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#metrics_config VaultCluster#metrics_config}
    */
    readonly metricsConfig?: VaultClusterMetricsConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#timeouts VaultCluster#timeouts}
    */
    readonly timeouts?: VaultClusterTimeouts;
}
export interface VaultClusterAuditLogConfig {
    /**
    * CloudWatch access key ID for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#cloudwatch_access_key_id VaultCluster#cloudwatch_access_key_id}
    */
    readonly cloudwatchAccessKeyId?: string;
    /**
    * CloudWatch region for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#cloudwatch_region VaultCluster#cloudwatch_region}
    */
    readonly cloudwatchRegion?: string;
    /**
    * CloudWatch secret access key for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#cloudwatch_secret_access_key VaultCluster#cloudwatch_secret_access_key}
    */
    readonly cloudwatchSecretAccessKey?: string;
    /**
    * Datadog api key for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#datadog_api_key VaultCluster#datadog_api_key}
    */
    readonly datadogApiKey?: string;
    /**
    * Datadog region for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#datadog_region VaultCluster#datadog_region}
    */
    readonly datadogRegion?: string;
    /**
    * ElasticSearch endpoint for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#elasticsearch_endpoint VaultCluster#elasticsearch_endpoint}
    */
    readonly elasticsearchEndpoint?: string;
    /**
    * ElasticSearch password for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#elasticsearch_password VaultCluster#elasticsearch_password}
    */
    readonly elasticsearchPassword?: string;
    /**
    * ElasticSearch user for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#elasticsearch_user VaultCluster#elasticsearch_user}
    */
    readonly elasticsearchUser?: string;
    /**
    * Grafana endpoint for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#grafana_endpoint VaultCluster#grafana_endpoint}
    */
    readonly grafanaEndpoint?: string;
    /**
    * Grafana password for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#grafana_password VaultCluster#grafana_password}
    */
    readonly grafanaPassword?: string;
    /**
    * Grafana user for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#grafana_user VaultCluster#grafana_user}
    */
    readonly grafanaUser?: string;
    /**
    * Splunk endpoint for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#splunk_hecendpoint VaultCluster#splunk_hecendpoint}
    */
    readonly splunkHecendpoint?: string;
    /**
    * Splunk token for streaming audit logs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#splunk_token VaultCluster#splunk_token}
    */
    readonly splunkToken?: string;
}
export declare function vaultClusterAuditLogConfigToTerraform(struct?: VaultClusterAuditLogConfigOutputReference | VaultClusterAuditLogConfig): any;
export declare class VaultClusterAuditLogConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VaultClusterAuditLogConfig | undefined;
    set internalValue(value: VaultClusterAuditLogConfig | undefined);
    private _cloudwatchAccessKeyId?;
    get cloudwatchAccessKeyId(): string;
    set cloudwatchAccessKeyId(value: string);
    resetCloudwatchAccessKeyId(): void;
    get cloudwatchAccessKeyIdInput(): string | undefined;
    get cloudwatchGroupName(): string;
    private _cloudwatchRegion?;
    get cloudwatchRegion(): string;
    set cloudwatchRegion(value: string);
    resetCloudwatchRegion(): void;
    get cloudwatchRegionInput(): string | undefined;
    private _cloudwatchSecretAccessKey?;
    get cloudwatchSecretAccessKey(): string;
    set cloudwatchSecretAccessKey(value: string);
    resetCloudwatchSecretAccessKey(): void;
    get cloudwatchSecretAccessKeyInput(): string | undefined;
    get cloudwatchStreamName(): string;
    private _datadogApiKey?;
    get datadogApiKey(): string;
    set datadogApiKey(value: string);
    resetDatadogApiKey(): void;
    get datadogApiKeyInput(): string | undefined;
    private _datadogRegion?;
    get datadogRegion(): string;
    set datadogRegion(value: string);
    resetDatadogRegion(): void;
    get datadogRegionInput(): string | undefined;
    get elasticsearchDataset(): string;
    private _elasticsearchEndpoint?;
    get elasticsearchEndpoint(): string;
    set elasticsearchEndpoint(value: string);
    resetElasticsearchEndpoint(): void;
    get elasticsearchEndpointInput(): string | undefined;
    private _elasticsearchPassword?;
    get elasticsearchPassword(): string;
    set elasticsearchPassword(value: string);
    resetElasticsearchPassword(): void;
    get elasticsearchPasswordInput(): string | undefined;
    private _elasticsearchUser?;
    get elasticsearchUser(): string;
    set elasticsearchUser(value: string);
    resetElasticsearchUser(): void;
    get elasticsearchUserInput(): string | undefined;
    private _grafanaEndpoint?;
    get grafanaEndpoint(): string;
    set grafanaEndpoint(value: string);
    resetGrafanaEndpoint(): void;
    get grafanaEndpointInput(): string | undefined;
    private _grafanaPassword?;
    get grafanaPassword(): string;
    set grafanaPassword(value: string);
    resetGrafanaPassword(): void;
    get grafanaPasswordInput(): string | undefined;
    private _grafanaUser?;
    get grafanaUser(): string;
    set grafanaUser(value: string);
    resetGrafanaUser(): void;
    get grafanaUserInput(): string | undefined;
    private _splunkHecendpoint?;
    get splunkHecendpoint(): string;
    set splunkHecendpoint(value: string);
    resetSplunkHecendpoint(): void;
    get splunkHecendpointInput(): string | undefined;
    private _splunkToken?;
    get splunkToken(): string;
    set splunkToken(value: string);
    resetSplunkToken(): void;
    get splunkTokenInput(): string | undefined;
}
export interface VaultClusterMajorVersionUpgradeConfig {
    /**
    * The maintenance day of the week for scheduled upgrades. Valid options for maintenance window day - `MONDAY`, `TUESDAY`, `WEDNESDAY`, `THURSDAY`, `FRIDAY`, `SATURDAY`, `SUNDAY`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#maintenance_window_day VaultCluster#maintenance_window_day}
    */
    readonly maintenanceWindowDay?: string;
    /**
    * The maintenance time frame for scheduled upgrades. Valid options for maintenance window time - `WINDOW_12AM_4AM`, `WINDOW_6AM_10AM`, `WINDOW_12PM_4PM`, `WINDOW_6PM_10PM`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#maintenance_window_time VaultCluster#maintenance_window_time}
    */
    readonly maintenanceWindowTime?: string;
    /**
    * The major upgrade type for the cluster. Valid options for upgrade type - `AUTOMATIC`, `SCHEDULED`, `MANUAL`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#upgrade_type VaultCluster#upgrade_type}
    */
    readonly upgradeType: string;
}
export declare function vaultClusterMajorVersionUpgradeConfigToTerraform(struct?: VaultClusterMajorVersionUpgradeConfigOutputReference | VaultClusterMajorVersionUpgradeConfig): any;
export declare class VaultClusterMajorVersionUpgradeConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VaultClusterMajorVersionUpgradeConfig | undefined;
    set internalValue(value: VaultClusterMajorVersionUpgradeConfig | undefined);
    private _maintenanceWindowDay?;
    get maintenanceWindowDay(): string;
    set maintenanceWindowDay(value: string);
    resetMaintenanceWindowDay(): void;
    get maintenanceWindowDayInput(): string | undefined;
    private _maintenanceWindowTime?;
    get maintenanceWindowTime(): string;
    set maintenanceWindowTime(value: string);
    resetMaintenanceWindowTime(): void;
    get maintenanceWindowTimeInput(): string | undefined;
    private _upgradeType?;
    get upgradeType(): string;
    set upgradeType(value: string);
    get upgradeTypeInput(): string | undefined;
}
export interface VaultClusterMetricsConfig {
    /**
    * CloudWatch access key ID for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#cloudwatch_access_key_id VaultCluster#cloudwatch_access_key_id}
    */
    readonly cloudwatchAccessKeyId?: string;
    /**
    * CloudWatch region for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#cloudwatch_region VaultCluster#cloudwatch_region}
    */
    readonly cloudwatchRegion?: string;
    /**
    * CloudWatch secret access key for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#cloudwatch_secret_access_key VaultCluster#cloudwatch_secret_access_key}
    */
    readonly cloudwatchSecretAccessKey?: string;
    /**
    * Datadog api key for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#datadog_api_key VaultCluster#datadog_api_key}
    */
    readonly datadogApiKey?: string;
    /**
    * Datadog region for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#datadog_region VaultCluster#datadog_region}
    */
    readonly datadogRegion?: string;
    /**
    * ElasticSearch endpoint for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#elasticsearch_endpoint VaultCluster#elasticsearch_endpoint}
    */
    readonly elasticsearchEndpoint?: string;
    /**
    * ElasticSearch password for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#elasticsearch_password VaultCluster#elasticsearch_password}
    */
    readonly elasticsearchPassword?: string;
    /**
    * ElasticSearch user for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#elasticsearch_user VaultCluster#elasticsearch_user}
    */
    readonly elasticsearchUser?: string;
    /**
    * Grafana endpoint for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#grafana_endpoint VaultCluster#grafana_endpoint}
    */
    readonly grafanaEndpoint?: string;
    /**
    * Grafana password for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#grafana_password VaultCluster#grafana_password}
    */
    readonly grafanaPassword?: string;
    /**
    * Grafana user for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#grafana_user VaultCluster#grafana_user}
    */
    readonly grafanaUser?: string;
    /**
    * Splunk endpoint for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#splunk_hecendpoint VaultCluster#splunk_hecendpoint}
    */
    readonly splunkHecendpoint?: string;
    /**
    * Splunk token for streaming metrics
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#splunk_token VaultCluster#splunk_token}
    */
    readonly splunkToken?: string;
}
export declare function vaultClusterMetricsConfigToTerraform(struct?: VaultClusterMetricsConfigOutputReference | VaultClusterMetricsConfig): any;
export declare class VaultClusterMetricsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VaultClusterMetricsConfig | undefined;
    set internalValue(value: VaultClusterMetricsConfig | undefined);
    private _cloudwatchAccessKeyId?;
    get cloudwatchAccessKeyId(): string;
    set cloudwatchAccessKeyId(value: string);
    resetCloudwatchAccessKeyId(): void;
    get cloudwatchAccessKeyIdInput(): string | undefined;
    get cloudwatchNamespace(): string;
    private _cloudwatchRegion?;
    get cloudwatchRegion(): string;
    set cloudwatchRegion(value: string);
    resetCloudwatchRegion(): void;
    get cloudwatchRegionInput(): string | undefined;
    private _cloudwatchSecretAccessKey?;
    get cloudwatchSecretAccessKey(): string;
    set cloudwatchSecretAccessKey(value: string);
    resetCloudwatchSecretAccessKey(): void;
    get cloudwatchSecretAccessKeyInput(): string | undefined;
    private _datadogApiKey?;
    get datadogApiKey(): string;
    set datadogApiKey(value: string);
    resetDatadogApiKey(): void;
    get datadogApiKeyInput(): string | undefined;
    private _datadogRegion?;
    get datadogRegion(): string;
    set datadogRegion(value: string);
    resetDatadogRegion(): void;
    get datadogRegionInput(): string | undefined;
    get elasticsearchDataset(): string;
    private _elasticsearchEndpoint?;
    get elasticsearchEndpoint(): string;
    set elasticsearchEndpoint(value: string);
    resetElasticsearchEndpoint(): void;
    get elasticsearchEndpointInput(): string | undefined;
    private _elasticsearchPassword?;
    get elasticsearchPassword(): string;
    set elasticsearchPassword(value: string);
    resetElasticsearchPassword(): void;
    get elasticsearchPasswordInput(): string | undefined;
    private _elasticsearchUser?;
    get elasticsearchUser(): string;
    set elasticsearchUser(value: string);
    resetElasticsearchUser(): void;
    get elasticsearchUserInput(): string | undefined;
    private _grafanaEndpoint?;
    get grafanaEndpoint(): string;
    set grafanaEndpoint(value: string);
    resetGrafanaEndpoint(): void;
    get grafanaEndpointInput(): string | undefined;
    private _grafanaPassword?;
    get grafanaPassword(): string;
    set grafanaPassword(value: string);
    resetGrafanaPassword(): void;
    get grafanaPasswordInput(): string | undefined;
    private _grafanaUser?;
    get grafanaUser(): string;
    set grafanaUser(value: string);
    resetGrafanaUser(): void;
    get grafanaUserInput(): string | undefined;
    private _splunkHecendpoint?;
    get splunkHecendpoint(): string;
    set splunkHecendpoint(value: string);
    resetSplunkHecendpoint(): void;
    get splunkHecendpointInput(): string | undefined;
    private _splunkToken?;
    get splunkToken(): string;
    set splunkToken(value: string);
    resetSplunkToken(): void;
    get splunkTokenInput(): string | undefined;
}
export interface VaultClusterTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#create VaultCluster#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#default VaultCluster#default}
    */
    readonly default?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#delete VaultCluster#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#update VaultCluster#update}
    */
    readonly update?: string;
}
export declare function vaultClusterTimeoutsToTerraform(struct?: VaultClusterTimeouts | cdktf.IResolvable): any;
export declare class VaultClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VaultClusterTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: VaultClusterTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster hcp_vault_cluster}
*/
export declare class VaultCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "hcp_vault_cluster";
    /**
    * Generates CDKTF code for importing a VaultCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VaultCluster to import
    * @param importFromId The id of the existing VaultCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VaultCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.73.0/docs/resources/vault_cluster hcp_vault_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VaultClusterConfig
    */
    constructor(scope: Construct, id: string, config: VaultClusterConfig);
    get cloudProvider(): string;
    private _clusterId?;
    get clusterId(): string;
    set clusterId(value: string);
    get clusterIdInput(): string | undefined;
    get createdAt(): string;
    private _hvnId?;
    get hvnId(): string;
    set hvnId(value: string);
    get hvnIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _minVaultVersion?;
    get minVaultVersion(): string;
    set minVaultVersion(value: string);
    resetMinVaultVersion(): void;
    get minVaultVersionInput(): string | undefined;
    get namespace(): string;
    get organizationId(): string;
    private _pathsFilter?;
    get pathsFilter(): string[];
    set pathsFilter(value: string[]);
    resetPathsFilter(): void;
    get pathsFilterInput(): string[] | undefined;
    private _primaryLink?;
    get primaryLink(): string;
    set primaryLink(value: string);
    resetPrimaryLink(): void;
    get primaryLinkInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _proxyEndpoint?;
    get proxyEndpoint(): string;
    set proxyEndpoint(value: string);
    resetProxyEndpoint(): void;
    get proxyEndpointInput(): string | undefined;
    private _publicEndpoint?;
    get publicEndpoint(): boolean | cdktf.IResolvable;
    set publicEndpoint(value: boolean | cdktf.IResolvable);
    resetPublicEndpoint(): void;
    get publicEndpointInput(): boolean | cdktf.IResolvable | undefined;
    get region(): string;
    get selfLink(): string;
    get state(): string;
    private _tier?;
    get tier(): string;
    set tier(value: string);
    resetTier(): void;
    get tierInput(): string | undefined;
    get vaultPrivateEndpointUrl(): string;
    get vaultProxyEndpointUrl(): string;
    get vaultPublicEndpointUrl(): string;
    get vaultVersion(): string;
    private _auditLogConfig;
    get auditLogConfig(): VaultClusterAuditLogConfigOutputReference;
    putAuditLogConfig(value: VaultClusterAuditLogConfig): void;
    resetAuditLogConfig(): void;
    get auditLogConfigInput(): VaultClusterAuditLogConfig | undefined;
    private _majorVersionUpgradeConfig;
    get majorVersionUpgradeConfig(): VaultClusterMajorVersionUpgradeConfigOutputReference;
    putMajorVersionUpgradeConfig(value: VaultClusterMajorVersionUpgradeConfig): void;
    resetMajorVersionUpgradeConfig(): void;
    get majorVersionUpgradeConfigInput(): VaultClusterMajorVersionUpgradeConfig | undefined;
    private _metricsConfig;
    get metricsConfig(): VaultClusterMetricsConfigOutputReference;
    putMetricsConfig(value: VaultClusterMetricsConfig): void;
    resetMetricsConfig(): void;
    get metricsConfigInput(): VaultClusterMetricsConfig | undefined;
    private _timeouts;
    get timeouts(): VaultClusterTimeoutsOutputReference;
    putTimeouts(value: VaultClusterTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | VaultClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
